"""
BindingDB_search_by_target

Search BindingDB for binding affinity data by target gene name or protein name. NOTE: BindingDB R...
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def BindingDB_search_by_target(
    query: str,
    target: Optional[str] = None,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> Any:
    """
    Search BindingDB for binding affinity data by target gene name or protein name. NOTE: BindingDB R...

    Parameters
    ----------
    query : str
        Target gene symbol or protein name (e.g., 'EGFR', 'BRAF', 'kinase')
    target : str
        Alias for query. Target gene symbol or protein name.
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    Any
    """
    # Handle mutable defaults to avoid B006 linting error

    # Strip None values so optional parameters don't trigger schema validation errors
    _args = {
        k: v for k, v in {"query": query, "target": target}.items() if v is not None
    }
    return get_shared_client().run_one_function(
        {
            "name": "BindingDB_search_by_target",
            "arguments": _args,
        },
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["BindingDB_search_by_target"]
